import fs from 'fs';
import { loggingLocal } from './router.js';
import { getSingleLog } from './routerUtils.js';
// const __dirname = url.fileURLToPath(new URL('.', import.meta.url));
let sendNewLogToClient = function (props) { };
const coloredConsoleLog = (text, color = 'black', ...notColoredTexts) => {
    const colors = {
        black: "\x1b[30m",
        red: "\x1b[31m",
        green: "\x1b[32m",
        yellow: "\x1b[33m",
        blue: "\x1b[34m",
        magenta: "\x1b[35m",
        cyan: "\x1b[36m",
        white: "\x1b[37m",
        console_color: '\x1b[0m'
    };
    const coloredText = `${colors[color]}${text}${colors.console_color} ${notColoredTexts}`;
    console.log(coloredText);
};
class OurLogging {
    // for tell user if he not pass logdir and filename
    logUsedAtLeastOnse = false;
    loggingBrowserLength;
    historyLogsLength;
    #logFileName;
    #logDir;
    constructor(historyLogsLength) {
        const defaultLength = 100;
        this.loggingBrowserLength = 80;
        this.historyLogsLength = historyLogsLength || defaultLength;
    }
    setBrowserMessagesAmount(amount) { this.loggingBrowserLength = amount; }
    setLogDir(dir) { this.#logDir = dir; }
    setLogfileName(name) { this.#logFileName = name; }
    fatal(text, stackTrace = '') {
        const currentTime = this.#getDateTime();
        let logText = `\n[ FATAL ERROR ] ${currentTime} | ${text}  ${stackTrace}`;
        coloredConsoleLog('[ FATAL ERROR ]', 'red', `${currentTime} | ${text} ${stackTrace}`);
        this.#addLogToGlobal(text + ' ' + stackTrace, 'fatal');
        this.#logTextToFile(logText);
        this.logUsedAtLeastOnse = true;
    }
    error(text) {
        const currentTime = this.#getDateTime();
        let logText = `\n[ ERROR ] ${currentTime} | ${text}`;
        coloredConsoleLog('[ ERROR ]', 'red', `${currentTime} | ${text}`);
        this.#addLogToGlobal(text, 'error');
        this.#logTextToFile(logText);
        this.logUsedAtLeastOnse = true;
    }
    warn(text) {
        const currentTime = this.#getDateTime();
        let logText = `\n[ WARNING ] ${currentTime} | ${text}`;
        coloredConsoleLog('[ WARNING ]', 'yellow', `${currentTime} | ${text}`);
        this.#addLogToGlobal(text, 'warn');
        this.#logTextToFile(logText);
        this.logUsedAtLeastOnse = true;
    }
    important(text) {
        const currentTime = this.#getDateTime();
        let logText = `\n[ IMPORTANT ] ${currentTime} | ${text}`;
        coloredConsoleLog('[ IMPORTANT ]', 'blue', `${currentTime} | ${text}`);
        this.#addLogToGlobal(text, 'info');
        this.#logTextToFile(logText);
        this.logUsedAtLeastOnse = true;
    }
    info(text) {
        const currentTime = this.#getDateTime();
        let logText = `\n[ INFO ] ${currentTime} | ${text}`;
        coloredConsoleLog('[ INFO ]', 'cyan', `${currentTime} | ${text}`);
        this.#addLogToGlobal(text, 'info');
        this.#logTextToFile(logText);
        this.logUsedAtLeastOnse = true;
    }
    success(text) {
        const currentTime = this.#getDateTime();
        let logText = `\n[ SUCCESS ] ${currentTime} | ${text}`;
        coloredConsoleLog('[ SUCCESS ]', 'green', `${currentTime} | ${text}`);
        this.#addLogToGlobal(text, 'success');
        this.#logTextToFile(logText);
        this.logUsedAtLeastOnse = true;
    }
    #addLogToGlobal(text, type) {
        if (loggingLocal.length > this.loggingBrowserLength)
            loggingLocal.shift();
        loggingLocal.push({ text, type, date: new Date().getTime() });
        sendNewLogToClient({ text, type, date: new Date().getTime() });
    }
    #getDateTime() {
        var currentDate = new Date();
        const date = currentDate.toLocaleDateString('en-US');
        const time = currentDate.toLocaleTimeString('en-US');
        return `${date} | ${time}`;
    }
    #logTextToFile(logText) {
        if (!this.#logFileName)
            return this.logUsedAtLeastOnse ? undefined : coloredConsoleLog('Path to log file is not provided', 'yellow');
        if (!this.#logDir)
            return this.logUsedAtLeastOnse ? undefined : coloredConsoleLog('Path to log file dir is not provided', 'yellow');
        if (!fs.existsSync(this.#logDir))
            fs.mkdirSync(this.#logDir);
        try {
            fs.appendFileSync(this.#logFileName, logText);
        }
        catch (error) {
            console.error(coloredConsoleLog('LOGGING ERROR: ', 'red', error.message));
        }
    }
}
const logging = new OurLogging();
export default logging;
export * from './router.js';
export const loggingWS = (ws) => {
    sendNewLogToClient = function (props) {
        ws.send(JSON.stringify({
            newLog: getSingleLog(props.type, props.date, props.text)
        }));
    };
};
