import expressWs, { WebsocketRequestHandler } from "express-ws"


/**
 * Express router, method: GET. Will send HTML with logs
 * Will create WebSocket and recieve all new logs from it
 * @param host expamle: 192.168.0.222
 * @param port example: 3000
 * @param routeName example: /log
 * @example const loggingRouter = getLoggingRouter(HOST, PORT)
 * app.use(loggingRouter)
 */
export function getLoggingRouter(host: string, port: number, routeName: string): expressWs.Router

// /**
//  * middleware for express ws
//  * @example app.ws('/some-route', loggingWS)
//  */
// export const loggingWS: WebsocketRequestHandler

interface Ilogging {
    /** 
     * Default: 80
     * @param amount Maximum logs stores in memory.
     * Hense only that amount will send to client
    */
    setBrowserMessagesAmount(amount: number): void

    /**
     * 
     * @param dir full path to directory with logs
     */
    setLogDir(dir: string): void

    /**
     * 
     * @param name full path to file with logs
     */
    setLogfileName(name: string): void

    /**
     * Use only for most important staff like db connection
     * @param text will be seen first by user
     * @param stackTrace will be showed after text and logged into file
     */
    fatal(text: string, stackTrace?: string): void

    /**
     * Important but not cicritical errors
     * @param text 
     */
    error(text: string): void

    /**
     * Some suspicious things, noticeable in console
     * EG on server start database logging turn off
     * @param text 
     */
    warn(text: string): void

    /**
     * Some important things, noticeable in console
     * @param text 
     */
    important(text: string): void

    /**
     * Not noticeable in console
     * @param text 
     */
    info(text: string): void

    /**
     * Noticeable in console, green color
     * @param text 
     */
    success(text: string): void
}

declare const logging: Ilogging

export default logging